@@ -1,33 +1,30 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_GTK_VERSION_H
-#define RETRO_GTK_VERSION_H
+/**
+ * SECTION:retro-gtk-version
+ * @short_description: Version checking
+ * @title: Version
+ */
+
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
 #endif
 
-/**
- * SECTION:retro-gtkversion
- * @short_description: retro-gtk version checking
- *
- * retro-gtk provides macros to check the version of the library
- * at compile-time
- */
-
 /**
  * RETRO_GTK_MAJOR_VERSION:
  *
  * retro-gtk major version component (e.g. 1 if %RETRO_GTK_VERSION is 1.2.3)
  */
-#define RETRO_GTK_MAJOR_VERSION (0)
+#define RETRO_GTK_MAJOR_VERSION (1)
 
 /**
  * RETRO_GTK_MINOR_VERSION:
  *
  * retro-gtk minor version component (e.g. 2 if %RETRO_GTK_VERSION is 1.2.3)
  */
-#define RETRO_GTK_MINOR_VERSION (16)
+#define RETRO_GTK_MINOR_VERSION (0)
 
 /**
  * RETRO_GTK_MICRO_VERSION:
@@ -41,7 +38,7 @@
  *
  * retro-gtk version.
  */
-#define RETRO_GTK_VERSION (0.16.1)
+#define RETRO_GTK_VERSION (1.0.1)
 
 /**
  * RETRO_GTK_VERSION_S:
@@ -49,7 +46,7 @@
  * retro-gtk version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define RETRO_GTK_VERSION_S "0.16.1"
+#define RETRO_GTK_VERSION_S "1.0.1"
 
 #define RETRO_GTK_ENCODE_VERSION(major,minor,micro) \
         ((major) << 24 | (minor) << 16 | (micro) << 8)
@@ -77,5 +74,3 @@
          (RETRO_GTK_MAJOR_VERSION == (major) && RETRO_GTK_MINOR_VERSION > (minor)) || \
          (RETRO_GTK_MAJOR_VERSION == (major) && RETRO_GTK_MINOR_VERSION == (minor) && \
           RETRO_GTK_MICRO_VERSION >= (micro)))
-
-#endif /* RETRO_GTK_VERSION_H */
